flutter_oboe

Oboe audio engine plugin for android!

Getting Started

This project is a basic sample of how to use Oboe audio engine from google inside the flutter project.

Note: Oboe is not available for iOS yet so that you need to handle things seperately if you're building from iOS.

Configuration requirements for android If you're using path_provider package, make sure yoour target and compile SDLK For the android is 31 Note: Make sure you add the correct permissions or it will not record the sound.