OboeTestStream class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void -
getSampleRate(
) → int -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
performNativeAdd(
int a, int b) → int -
start(
) → void -
startTestRecording(
String path, int recordingFrequency) → void -
stop(
) → void -
stopTestRecording(
) → void -
toString(
) → String -
A string representation of this object.
inherited
-
write(
Float32List original) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited